@@ -33,8 +33,10 @@
 #include "ext_max_record.h"
 #include <ext_cert_type.h>
 #include <ext_server_name.h>
+#include <ext_oprfi.h>
 #include <ext_srp.h>
 #include <ext_inner_application.h>
+#include <ext_authz.h>
 #include <gnutls_num.h>
 
 /* Key Exchange Section */
@@ -49,12 +51,25 @@ gnutls_extension_entry _gnutls_extensions[MAX_EXT_SIZE] = {
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_MAX_RECORD_SIZE,
 			  _gnutls_max_record_recv_params,
 			  _gnutls_max_record_send_params),
+#ifdef ENABLE_AUTHZ
+  GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_AUTHZ_CLIENT,
+			  _gnutls_authz_ext_client_recv_params,
+			  _gnutls_authz_ext_client_send_params),
+  GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_AUTHZ_SERVER,
+			  _gnutls_authz_ext_server_recv_params,
+			  _gnutls_authz_ext_server_send_params),
+#endif
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_CERT_TYPE,
 			  _gnutls_cert_type_recv_params,
 			  _gnutls_cert_type_send_params),
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_SERVER_NAME,
 			  _gnutls_server_name_recv_params,
 			  _gnutls_server_name_send_params),
+#ifdef ENABLE_OPRFI
+  GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_OPAQUE_PRF_INPUT,
+			  _gnutls_oprfi_recv_params,
+			  _gnutls_oprfi_send_params),
+#endif
 #ifdef ENABLE_SRP
   GNUTLS_EXTENSION_ENTRY (GNUTLS_EXTENSION_SRP,
 			  _gnutls_srp_recv_params,
